copy_block

Function copy_block 

pub fn copy_block(out: &mut [f32], src: &[f32])
out[i] = src[i]. Equivalent to copy_from_slice but exposed in the same surface as the other ops for code that wires up its inner loops from this module.